@@ -13,6 +13,7 @@ from subprocess import check_call
 from tempfile import TemporaryDirectory
 from typing import TYPE_CHECKING, Optional, Union
 
+import htmlmin
 import pandas as pd
 import yaml
 from botocore.exceptions import ClientError
@@ -52,7 +53,6 @@ DATASETS = BOOK_DIR / "datasets"
 
 class S3Remote:
     def __init__(self, remote_id):
-
         z_auth = get_full_auth()
         self.bucket = z_auth.get_boto_bucket(remote_id)
         auth = z_auth.get_auth(remote_id)
@@ -372,9 +372,8 @@ class _NBParser:
 
 
 def get_profile_str(df, minimal):
-
     from bs4 import BeautifulSoup, Tag
-    from pandas_profiling import ProfileReport
+    from ydata_profiling import ProfileReport
 
     profile = ProfileReport(df, minimal=minimal)
     soup = BeautifulSoup(profile.to_html(), "html5lib")
@@ -397,7 +396,7 @@ def get_profile_str(df, minimal):
 
     soup.find("body").insert(-1, bs_script)
     soup.find("body").insert(-2, jq_script)
-    return str(soup)
+    return htmlmin.minify(str(soup), remove_comments=True, remove_empty_space=True)
 
 
 def _title(s):
