@@ -81,4 +81,4 @@ def get_sa_type(dtype: Type):
 def get_np_type(dtype: Type, nullable: bool):
     if nullable and (dtype == str):
         dtype = object
-    return {datetime: "datetime64[ns]"}.get(dtype, dtype)
+    return {datetime: "datetime64[ns, UTC]"}.get(dtype, dtype)
