@@ -14,6 +14,7 @@ from flit.build import main
 from structlog import get_logger
 
 from .config_loading import get_full_auth
+from .metadata.high_level import PROJ_KEYS
 from .naming import (
     GIT_TOKEN_ENV_VAR,
     MAIN_MODULE_NAME,
@@ -25,8 +26,9 @@ from .naming import (
     VERSION_VAR_NAME,
     RegistryPaths,
     get_package_name,
+    to_mod_name,
 )
-from .utils import gen_rmtree, git_run
+from .utils import command_out_w_prefix, gen_rmtree, git_run
 
 if TYPE_CHECKING:
     from .config_loading import Config  # pragma: no cover
@@ -56,12 +58,23 @@ class Registry:
         self._git_run = partial(git_run, wd=self.posix)
 
     def dump_info(self):
-        meta_dic = self._get_info()
+        meta_dic = self.get_info()
         self.paths.info_yaml.write_text(yaml.safe_dump(meta_dic))
 
+    def get_info(self):
+        remote_comm = ["git", "config", "--get", "remote.origin.url"]
+        try:
+            uri = check_output(remote_comm).decode("utf-8").strip()
+        except CalledProcessError:
+            uri = ""
+            logger.info("can't get git remote.origin.url")
+        return {
+            PROJ_KEYS.uri: _de_auth(uri),
+            PROJ_KEYS.tags: self._get_tags(),
+            PROJ_KEYS.cron: self.conf.cron,
+        }
+
     def get_project_meta_base(self, project_name, version):
-        if project_name == self.name:
-            return self._get_info()
         ypath = self.paths.info_yaml_of(project_name, version)
         if ypath.exists():
             return yaml.safe_load(ypath.read_text())
@@ -72,9 +85,8 @@ class Registry:
         get_full_auth().dump_dvc(local=not global_conf)
         if not self._is_released():
             self._package()
-        if not self.requires:
-            return
-        self._install_no_server(self.requires)
+        if self.requires:
+            self._install_no_server(self.requires)
 
     def update(self):
         self._git_run(pull=True)
@@ -82,12 +94,13 @@ class Registry:
     def publish(self):
         self.dump_info()
         msg = f"push {self.name}-{self.conf.version}"
-        self._git_run(add=self.paths.publish_paths, msg=msg, push=True, pull=True)
+        vc_paths = self.paths.publish_paths
+        self._git_run(add=vc_paths, msg=msg, push=True, pull=True, check=True)
 
     def purge(self):
         gen_rmtree(self.posix)
         freeze_comm = [sys.executable, "-m", "pip", "freeze"]
-        all_dz_projects = [*_command_out_w_prefix(freeze_comm, f"{META_MODULE_NAME}-")]
+        all_dz_projects = [*command_out_w_prefix(freeze_comm, f"{META_MODULE_NAME}-")]
         if not all_dz_projects:
             return
         check_call([sys.executable, "-m", "pip", "uninstall", *all_dz_projects, "-y"])
@@ -95,6 +108,7 @@ class Registry:
     def _package(self):
         pack_paths = self._dump_meta()
         reqs_from_txt = REQUIREMENTS_FILE.read_text().strip().split("\n")
+        mod_name = to_mod_name(self.name)
         proj_conf = {
             "project": {
                 "name": get_package_name(self.name),
@@ -103,20 +117,20 @@ class Registry:
                 "requires-python": PYV,
                 "dependencies": self.requires + reqs_from_txt,
             },
-            "tool": {"flit": {"module": {"name": f"{META_MODULE_NAME}.{self.name}"}}},
+            "tool": {"flit": {"module": {"name": f"{META_MODULE_NAME}.{mod_name}"}}},
         }
         pack_paths.toml_path.write_text(toml.dumps(proj_conf))
         ns = main(pack_paths.toml_path)
         copy(ns.sdist.file, self.paths.index_dir)
         copy(ns.wheel.file, self.paths.index_dir)
-        return True
+        return ns.sdist.file
 
     def _install_no_server(self, packages: list):
         addr = self.paths.index_dir.as_posix()
         comm = [sys.executable, "-m", "pip", "install", f"--find-links={addr}"]
         extras = ["--no-cache", "--no-build-isolation"]
         backup_ind = ["--extra-index-url", "https://pypi.org/simple"]
-        check_call(comm + backup_ind + extras + packages, stdout=PIPE)
+        check_call(comm + backup_ind + extras + packages)  # TODO: , stdout=PIPE)
 
     def _dump_meta(self):
         pack_paths = PackPaths(self.name)
@@ -128,13 +142,7 @@ class Registry:
 
     def _get_tags(self):
         tagpref = VERSION_SEPARATOR.join([VERSION_PREFIX, self.conf.version])
-        return [*_command_out_w_prefix(["git", "tag"], tagpref)]
-
-    def _get_info(self):
-        remote_comm = ["git", "config", "--get", "remote.origin.url"]
-        uri = check_output(remote_comm).decode("utf-8").strip()
-        # WET Project metadata params
-        return {"uri": _de_auth(uri), "tags": self._get_tags(), "cron": self.conf.cron}
+        return list(command_out_w_prefix(["git", "tag"], tagpref))
 
     def _is_released(self):
         try:
@@ -164,12 +172,4 @@ class PackPaths:
         self.dir = Path(TemporaryDirectory().name)
         _meta_root = self.dir / META_MODULE_NAME
         self.toml_path = self.dir / "pyproject.toml"
-        self.project_meta = _meta_root / name
-
-
-def _command_out_w_prefix(comm, prefix):
-    for tagbytes in check_output(comm).strip().split():
-        tag = tagbytes.decode("utf-8").strip()
-        if not tag.startswith(prefix):
-            continue
-        yield tag
+        self.project_meta = _meta_root / to_mod_name(name)
