@@ -12,12 +12,8 @@ from structlog import get_logger
 from yaml import safe_load
 
 from datazimmer.explorer import SETUP_DIR
-from datazimmer.naming import (
-    BASE_CONF_PATH,
-    EXPLORE_CONF_PATH,
-    MAIN_MODULE_NAME,
-    TEMPLATE_REPO,
-)
+from datazimmer.naming import BASE_CONF_PATH, EXPLORE_CONF_PATH, MAIN_MODULE_NAME
+from datazimmer.typer_commands import init
 from datazimmer.utils import cd_into, gen_rmtree, git_run, package_root
 
 logger = get_logger()
@@ -26,18 +22,15 @@ dogshow_root = package_root / "dogshow"
 project_cc_root = dogshow_root / "projects"
 dec_src_root = dogshow_root / "explorer"
 
-_PROJECTS = ["dogshowbase", "dogracebase", "dogsuccess", "dogcombine"]
-_VERSIONS = {"dogshowbase": ["0.0", "0.1"], "dogsuccess": ["1.0"]}
+_PROJECTS = ["dog-raw", "dog-show", "dograce", "dogsuccess", "dogcombine"]
+_VERSIONS = {"dog-show": ["0.0", "0.1"], "dogsuccess": ["1.0"]}
+_RAW_IMPORTS = {"dog-show": ["dog-raw"], "dograce": ["dog-raw"]}
+_PRIVATE_ZEN = {"dogsuccess": "sex_matches"}
 
 
 class DogshowContextCreator:
     def __init__(
-        self,
-        local_root,
-        csv_path,
-        remote_root=None,
-        dvc_remotes=None,
-        explore_remote=None,
+        self, local_root, remote_root=None, dvc_remotes=None, explore_remote=None
     ):
         self.local_root = Path(local_root)
         gen_rmtree(self.local_root)
@@ -47,7 +40,6 @@ class DogshowContextCreator:
         self.dvc_remotes = [*self._get_dvc_remotes(dvc_remotes)]
         _reg = self.remote_root / "dogshow-registry"
         self.cc_context = {
-            "csv_path": csv_path,
             "test_registry": self._init_if_local(_reg, True),
             "explore_remote": json.dumps(explore_remote),
             "remote2": self.dvc_remotes[1][0],
@@ -56,13 +48,11 @@ class DogshowContextCreator:
 
     @contextmanager
     def project_ctx(self, name: str):
-        root_dir = self.local_root / name
-        root_dir.mkdir()
-        template_path = project_cc_root / f"cc-{name}"
         git_remote = self._init_if_local(self.remote_root / f"dogshow-{name}")
-        check_call(["git", "clone", TEMPLATE_REPO, root_dir.as_posix()])
-        Path(root_dir, MAIN_MODULE_NAME, "core.py").unlink()
-        check_call(["git", "remote", "set-url", "origin", git_remote], cwd=root_dir)
+        with cd_into(self.local_root):
+            init(name, git_remote=git_remote)
+        root_dir = self.local_root / name
+        template_path = project_cc_root / f"cc-{name}"
         generate_files(
             template_path,
             {"cookiecutter": {"project": name}, **self.cc_context},
@@ -72,12 +62,12 @@ class DogshowContextCreator:
         self.ran_dirs.append(root_dir)
         with cd_into(root_dir):
             sys.path.insert(0, Path.cwd().as_posix())
-            _add_readme()
             for remote_name, remote_id in self.dvc_remotes:
                 check_call(["dvc", "remote", "add", remote_name, remote_id])
             check_call(["dvc", "remote", "default", self.dvc_remotes[0][0]])
-            git_run(add=["*"], msg="setup project")
-            yield name, _VERSIONS.get(name, [])
+            git_run(add=["*"], msg=f"setup {name} project", push=True)
+            pzen = _PRIVATE_ZEN.get(name, "")
+            yield name, _VERSIONS.get(name, []), _RAW_IMPORTS.get(name, []), pzen
             sys.path.pop(0)
 
     def explorer(self):
@@ -114,10 +104,7 @@ class DogshowContextCreator:
     @classmethod
     def load(cls, mode: str, tmp_path: Path):
         if mode == "test":
-            kwargs = {
-                "csv_path": Path(dogshow_root, "data").absolute().as_posix(),
-                "local_root": tmp_path,
-            }
+            kwargs = {"local_root": tmp_path}
         else:  # pragma: no cover
             kwargs = safe_load((dogshow_root / "confs-live.yaml").read_text())[mode]
         return cls(**kwargs)
@@ -160,10 +147,7 @@ def modify_to_version(version: str):
                 new_line = old_line
             lines.append(new_line)
         path.write_text("\n".join(lines))
-
-
-def _add_readme():
-    Path("README.md").write_text(f"test project for [this]({TEMPLATE_REPO}) template")
+    git_run(add=[MAIN_MODULE_NAME, BASE_CONF_PATH], msg=f"v{version}", check=True)
 
 
 def _get_paths():
